No Title
Author: root
Keywords: syntax

# FTBL-Data

## Introduction

The Carbon-Flux-Labeling-Toolkit is used to simulate the distribution of 13C-labeled substrate in a micro-biological organism. The tool therefore needs some information about the network of reactions in the organism. The simulation is mostly used, to get some knowledge about the reaction (flux) rates in that organism. For this it is possible to fit simulated labeling patterns to labels that are measured in experiments.
To give the user of this tool a convenient way to build a model for reactions (label-transitions) and measurements (label-distribution) a file-format was created.
A file using this format is called a FTBL-File (an abbreviation for Flux-TaBLe-File). As the name says, it's a file using a tabular scheme and so it seems best to use a spreadsheet application like StarCalc or Excel to edit such a file.

The following text is a description of the syntactical and structural format of such a file.

## Contents and structure of FTBL files

### Block Structure

Generally spoken, the data in a FTBL-File is oriented in blocks. A block can contain either subblocks or data. This hierarchical structure of blocks and subblocks give the creator of the file a good oversight of the information that is given and makes it easy for the simulation-tool to parse this information. A typical block-scheme is shown in the following table below.

Block header 1 |  |  |  |
| column header 1 | column header 2 | column header 3 | column header 4
| x | x | x | x
| x | x | x | x
| x | x | x | x
| x | x | x | x

Block header 2 |  |  |  |
| column header 1 | column header 2 | column header 3 |
| x | x | x |
| x | x | x |
| x | x | x |
| x | x | x |

As you can see, a block is some kind of rectangular data made of columns and rows. It can be typed by an editor but best with some kind of spreadsheet-software.

Each (sub-)block starts with a keyword called block header. The fields under the block header must be empty until the next block on the same level of hierarchy starts. This is the only way to separate blocks from subsequent blocks in the same level. So a new subblock starts in the next column (and possibly in the next row) as it is shown at the table above.

(!!! ACHTUNG: Es stimmt nicht, daß ein SUBBLOCK in der nächsten Zeile starten muß. Siehe Beispiel MS-Data. Wir sollten es aber auf jeden Fall ermöglichen. D.h. ein Subblock wird nachdem er erkannt wurde erst mal von Leerzeilen befreit. Es sind also Änderungen nötig, die das Erkennen von Subblöcken angeht.!!!)

A data block is written in tabular form. Each data table starts with a row naming the information that can be found in the columns of data below that row. Such a special rows (subblock) is called header block. The order of the column headers and the column header itself must not be changed. In this way the contents of each row is unambiguously specified.

###
FTBLData syntax and structure

In a FTBLData file following block headers must exist:

- [NETWORK]

- [FLUXES]

- [EQUALITIES]

- [INEQUALITIES]

- [FLUX_MEASUREMENTS]

- [LABEL_INPUT]

- [LABEL_MEASUREMENT]

- [PEAK_MEASUREMENT]

- [MASS_SPECTROMETRY]

- [OPTIONS]

Each block with the affiliated block header must occur exactly once. The order in wich these blocks appear is free.

#### NETWORK

The NETWORK subblock contains one header-block and some subblocks called reactions. These reactions describe the flux network of the carbon-atoms and therefore the reactions are also called fluxes.

##### Structure

An reaction-block has two data rows. The first row names the flux and some metabolites. The second row - the atom entries - is a indexing system for the transition of carbon-atoms from one metabolite to another by this reaction.

FLUX_NAME | EDUCT_1 | EDUCT_2 | PRODUCT_1 | PRODUCT_2
f1 | m1 |  | m2 |
| #ABCDEF |  | #ABCDEF |
f2 | m3 | m4 | m5 | m6
| #ABCDEF | #abc | #ABbcEF | #DCa

Due to technical reasons of the simulation software a reaction can only have a maximum of two educts and two products. Reactions having more educts or products must be formulated using intermediate-metabolites.
The atom entry must be placed exactly under the related metabolite entry (e.g. in the flux f1 the related atom entry of the metabolite m1 is #ABCDEF. Or in flux f2 the atom entry of m5 is #ABbcEF). In the row of atom entries the entry of FLUX_NAME must be empty.

##### Syntax

The flux names, the educt and product names in the first row of each flux have to match the regular expression [a-zA-Z][a-zA-Z_0-9]*, the atom entries in the following row must match #[a-zA-Z0-9]+ .

##### Consistency

Flux-names must not be unique in NETWORK. Input- and output-fluxes must have only one educt and one product. An atom-entries must correspond in educts and product and the transposition must be clear. That means and index 'A' in an educt can only be used in an product once again.

The way the reaction is noted determines some flux terms. Because bidirectional reaction should be simulated it's not that fix, what's an educt or product for a reaction. It must be distinguished between forward and backward reactions/fluxes.
A forward flux tells something about the rate with which the reaction reacts from educts to products. The backward flux rates the opposite reaction from products to educts. Forward- and backward-fluxes can only have positive values.
An other view on reaction rates is described by net- and exchange fluxes. A net-flux quantifies the net reaction rate for a flux. So if a net-flux is negative is means that a reaction transports more molecules from product to educt than from educt to product. The exchange-flux holds the rate with which the reaction transforms educt to products and to educts again.
Having an exchange-flux unequal zero means that reactions in both directions take place. Having an exchange-flux being zero declares an unidirectional flux.
Both forward/backward-values and net/exchange-values can be transformed in each other.

#### EQUALITIES

##### Structure

In this block dependencies between fluxes can be set. Like the FLUXES block the equalities are divided in two groups - in net and exchange fluxes.

NET |  |  |
| VALUE | FORMULA |
| 0.5 | 2 f3+f7-4 f8 |
| 0.0 | f4-5 f2 | // f4 = 5*f2
XCH |  |  |
| VALUE | FORMULA |
| 0.001 | f6-f3 | // f6 = f3

In FORMULA a linear combination of parametriced fluxes is given. The fluxes must be determined by the simulation that the formula must result in VALUE. See comments in the example.

##### Syntax

VALUE entry must be a floating-point number. In FORMULA a linear combination of fluxes must be given.

##### Consistency

All fluxes used in FORMULA must be defined in NETWORK.

#### FLUXES

The relations between the fluxes given in the NETWORK block and the additional equality-constraints given in the EQUALITIES block most of the time don't determine all fluxes of the network. In this FLUXES block the missing determining fluxes have to be given.
It's not seldom that there is a great freedom in the way these missing fluxes can be chosen to determine the flux-network. There are independent and dependent fluxes. By choosing and setting independent fluxes the dependent fluxes can be calculated.
This block list:

- Independent Fluxes:

  - Free fluxes can varied by an optimization to best fit measured labels and measured flux-rates.

  - Constrained fluxes are set by the user to fix values. These flux-rated aren't varied by an optimization.

- Dependent fluxes: These can't be chosen. They are calculated by the values of free and constrained fluxes and the conditions of the stochiometric and equality information.

The dependent fluxes needn't be listed but an interactive tool that supports the choosing of independent fluxes will be developed. It will be possible to switch dependent to independent fluxes. So this block should list all fluxes declared in the NETWORK block.

##### Structure

The block FLUXES contains two subblocks - NET and XCH - as shown below.

NET |  |  |  |  |  |
| NAME | FCD | VALUE(F/C) | LOW(F) | INC(F) | UP(F)
| f2 | F | 0.5 | 0.0 | 0.1 | 1.0
| f3 | D |  |  |  |
| f7 | C | 0.2 |  |  |
XCH |  |  |  |  |  |
| NAME | FCD | VALUE(F/C) | LOW(F) | INC(F) | UP(F)
| f4 | F | 0.3 |  |  |
| f5 | C | 0.83 |  |  |
| f6 | F | 0.24 | 0 | #10 | 1

In each subblock you have a table with following columns: NAME gives the flux-name, FCD tells if the flux is free,constrained or dependent. If the flux is free or constrained a value for the flux must be given in VALUE(F/C). If the flux is free you can give an interval that is stepped through by some algorithms. (Not in use right now.) All flux values are given in net- and xch[0,1]-rates.

##### Syntax

For each text in NAME a flux must be given. In column FCD it must be specified either a flux is free (F), dependent (D), or constrained (C). The entries of VALUE(...) must be floating-point numbers. LOW(F) and UP(F) must be floating-point numbers. In INC(F) the step size as a floating-point can be given or the number of steps in between LOW and UP as an integer with an preceding '#'.

##### Consistency

Fluxes used in NAME must be defined in NETWORK. The Value in UP(F) must be greater than in LOW(F). INC(F) must have a positive value.

#### INEQUALITIES

##### Structure

Using inequalities further restriction for the fluxes can be formulated. In this block the fluxes are differentiated in net and exchange fluxes, too.

INEQUALITIES |  |  |  |
| NET |  |  |
|  | VALUE | COMP | FORMULA
|  | 0 | <= | f3
|  | 0.5 | >= | f3
| XCH |  |  |
|  | VALUE | COMP | FORMULA
|  | 0.2 | <= | f5+2 f7
|  | 0.7 | >= | f6

In both tables - NET for the net fluxes and XCH for the exchange fluxes - flux values are set, which must not be exceeded by a flux or a linear combination of fluxes. In VALUE this boundary is set. In COMP the type of comparison is given - less equal or greater equal - and in FORMULA a flux or a linear combination of these fluxes. It is not possible to formulate inequalities mixing net- and xch-fluxes. All flux values are given in net- and xch[0,1]-rates.

##### Syntax

VALUE entry must be a floating-point number. The entry of COMP must be either >= or <=. In FORMULA a linear combination of fluxes must be given.

##### Consistency

All fluxes used in FORMULA must be defined in NETWORK.

#### FLUX_MEASUREMENTS

##### Structure

For some net-fluxes measurement data exists. This data is specified in this block.

FLUX_MEASUREMENTS |  |  |
| FLUX_NAME | VALUE | DEVIATION
| f1 | 1 | 0.001
| f5 | 0.043 | 0.02

In column FLUX_NAME the flux name is entered, which has measured data. In the column VALUE the measurement is set. The standard deviation of this measurement must be given in the next column.

##### Syntax

In FLUX_NAME the name of a flux must be given. The entries of VALUE and DEVIATION must be floating-point numbers.

##### Consistency

Fluxes used in FLUX_NAME must be defined in NETWORK.

#### LABEL_INPUT

##### Structure

At this place the input metabolites are specified.

LABEL_INPUT |  |  |
| META_NAME | ISOTOPOMER | VALUE
| m1 | #100000 | 0.99
|  | #111111 | 0.01
| m7 | #11000 | 1.0

The column META_NAME contains the metabolite name for which the isotopomer settings should be specified. In the next column the isotopomers of this metabolite are listed. The VALUE column contains the fraction of this isotopomer in the substrate.

##### Syntax

In META_NAME a metabolite name must be specified. The entry of ISOTOPOMER must match the regular expression #(01)+ and VALUE must be floating-point number.

##### Consistency

Metabolites used in META_NAME must be defined in NETWORK first. The length of an ISOTOPOMER entry must be equal with the number of atoms of the metabolite specified in META_NAME plus the sign #. E.g. m1 has six C-atoms. Then the entry of ISOTOPOMER must have the length seven - first the sign # and then for each atom one 0 or 1.

#### LABEL_MEASUREMENTS

##### Structure

In this structure the label measurements are placed.

LABEL_MEASUREMENTS |  |  |  |  |
| META_NAME | CUM_GROUP | VALUE | DEVIATION | CUM_CONSTRAINTS
| m5 | Group1 | 0.1255 | 0.01 | #x1xx01+#x11xxx
|  |  | 0.1255 | 0.01 | #xxxx11+#xx1xxx
|  | Group2 | 0.1255 | 0.01 | #xx1x01+#xx11xx
|  |  | 0.1255 | 0.01 | #1xxx11+#1xxx10+#1xxx01
| m10 | Group1 | 0.3 | 0.008 | #x01
|  |  | 0.3 | 0.008 | #x10
|  |  | 0.3 | 0.008 | #x11

META_NAME contains the metabolite name for which the label measurements are known. In CUM_GROUP the label measurements could be separated in measurement groups. All Measurements in a group are scaled with a single factor to best fit the simulated cumomers with the measured value. In the following columns the values and the standard deviations of the measurements are given. The entries of CUM_CONSTRAINTS are sums of cumomers.

##### Syntax

In META_NAME a metabolite must be entered. CUM_GROUP can have one entry for each group. VALUE and DEVIATION must be floating-point numbers. The CUM_CONSTRAINTS expressions must match the regular expression #[01x]+(\+#[01x]+)*.

##### Consistency

Metabolites used in META_NAME must be defined in NETWORK. As described above the CUM_CONSTRAINTS are build of cumomer specifications. The length of each cumomer specification must be equal with number of atoms of the metabolite specified in META_NAME plus the sign #. E.g. m10 has two C-atoms. Then the cumomers in CUM_CONSTRAINTS must have the length three - first the sign # and then for each atom one x, 0 or 1.

#### PEAK_MEASUREMENTS

##### Structure

This block contains the 13C-NMR peak measurements.

#### PEAK_MEASUREMENTS |  |  |  |  |  |  |
| META_NAME | PEAK_NO | VALUE_S | VALUE_D- | VALUE_D+ | VALUE_DD | VALUE_T
| m5 | 2 | 0.2 | 0.23 | 0.03 |  |
|  | 1 | 0.11 |  |  |  |
| m6 | 2 | 0.132 | 0.25 |  |  | 0.221
| m8 | 3 | 0.31 | 0.27 | - | - |
|  | 2 | 0.14 | 0.15 | 0.14 | - |
|  | 1 | 0.1 |  |  |  |

DEVIATION_S | DEVIATION_D- | DEVIATION_D+ | DEVIATION_DD/T
1 | 0.001 | 0.001 |
0.02 |  |  |
0.003 |  |  | 0.003
0.002 | 0.002 |  |
0.021 |  |  |
0.01 |  |  |

In the first column META_NAME the metabolites are entered, which have peak measurement data. In the next column the peak number have to be insert. The peak number is the index of the carbon atom which produced the peak in NMR. The index is fixed by the entries in the NETWORK-block. The following columns contains the values their standard deviations of the peak measurements: VALUE_S is the column for singulett measurements, VALUE_D- for doublett measurements produced by the neighbor with the index one less then the peak number, VALUE_D+ for doublett measurements produced by the neighbor with index on greater than the peak number, VALUE_DD for double doublett measurements and VALUE_T for triplett measurements. DEVIATION_S contains the standard deviations of the singulett measurements, DEVIATION_D-/D these of the Value_D- doublett measurements, DEVIATION_D+ of the VALUE_D+ doublett measurements and DEVIATION_DD/T either of the double doublett or triplett measurements - depending on what measurement is given. All deviations field beside DEVIATION_S may be left empty. In this case their values are taken from the value in DEVIATION_S.

##### Syntax

In META_NAME a metabolite must be given. PEAK_NO entry must be an integer number. All other fields may either contain floating point numbers or may be empty (see Consistency)

##### Consistency

Fluxes used in NAME must be defined in NETWORK. PEAK_NO must be positive and less or equal with number of atoms of this metabolite. In the following table the permitted combinations of VALUE_* entries are listed:

VALUE_S | VALUE_D- | VALUE_D+ | VALUE_DD | VALUE_T | Comment
x |  |  |  |  | Only one singulett was mesured
x | - |  |  |  |
x | x |  |  |  | Only - this can be for the carbon atom at an end of an carbon-string
x | x | - | - |  | S and D- could be measured, D+ and DD couuld not be measured
x |  | x |  |  | S and D+ were the only peaks that can
x | - | x | - |  |
x | x |  |  | - |
x |  | x |  | - |
x | x | x |  |  |
x | x | x | - |  |
x | x |  |  | x |
x |  | x |  | x |
x | x | x | x |  |

In this table x is a variable for a given peak measurement.

#### MASS_SPECTROMETRY

##### Structure

In this block the mass spectrometry data is specified.

MASS_SPECTROMETRY |  |  |  |  |
| META_NAME | FRAGMENT | WEIGHT | VALUE | DEVIATION
| m5 | 1,4~6 | 0 | 0.01 | 0.001
|  |  | 1 | 0.12 | 0.002
|  |  | 2 | 0.03 | 0.004
|  |  | 3 | 0.01 | 0.002
|  |  | 4 | 0.07 | 0.001
|  | 1,2 | 0 | 0.1 | 0.003
|  |  | 1 | 0.15 | 0.003
|  |  | 2 | 0.07 | 0.002
| m9 | 1,2,4~6 | 0 | 0.21 | 0.0011
|  |  | 1 | 0.23 | 0.0024
|  |  | 2 | 0.12 | 0.01
|  |  | 3 | 0.1 | 0.001
|  |  | 4 | 0.1 | 0.001
|  |  | 5 | 0.34 | 0.001

The first column META_NAME contains these metabolites for which the mass spectrometry data should be specified. In column FRACTION the fraction of the molecule that is measured is given. The column WEIGHT tells the relative weight to the unlabeled fraction. In the next two columns the value and the standard deviation of the measurement must be insert.

##### Syntax

In META_NAME a metabolite must be given. The expression of FRACTION must match the regular expression ([0-9]|([0-9]~[0-9]))(,([0-9]|([0-9]~[0-9])))*. WEIGHT must be an integer number, VALUE and DEVIATION entries are floating-point numbers.

##### Consistency

META_NAME must be declared in the NETWORK section. FRACTION entry must not contain a value greater than number of atoms of this metabolite. The number of weights must not be greater than number of atoms in FRACTION entry.

#### OPTIONS

## Error and warning messages

Before using a FTBLData file with the simulation or optimization program it will be automatically checked by a FTBL check program. This check program searches for syntax and consistency errors, which may occure in the FTBL file. Each error and warning message has a fix structure:

`error_number:block_name:line_in_block:column_in_block:ErrorText`

In the next sections all possible errors are listed.

## Localization of error and warning messages

Err_Part | example | description
block_name | MASS_SPECTROMETRY | Block
line_in_block | META_NAME=m8>FRACTION=1,2 | Line in block
column_in_block | ???? | Column in found row

## Tables of syntax and consistency messages

The following subsections give an overview about these possible happened errors. Further the errors are separated by the main blocks. The syntax error messages have the code SYN_####, the consistency errors CON_####, where #### is an error number.

In the following tables of error messages metabolite are metabolite and flux are flux variables.

### Syntax errors

The following table lists all syntax errors could be find and returned by the FTBL check program:

Error code | Error messages | Link
SYN_0001 | Block NETWORK can not be found |
SYN_0002 | Block FLUXES can not be found. |
SYN_0003 | Block INEQUALITIES can not be found. |
SYN_0004 | Block EQUALITIES can not be found. |
SYN_0005 | Block LABEL_INPUT can not be found. |
SYN_0006 | Block FLUX_MEASUREMENTS can not be found. |
SYN_0007 | Block LABEL_MEASUREMENTS can not be found. |
SYN_0008 | Block PEAK_MEASUREMENTS can not be found. |
SYN_0009 | Block MASS_SPECTROMETRY can not be found. |
SYN_0010 | Block OPTIONS can not be found. |
SYN_0011 | Block PROJECT can not be found. |

#### NETWORK

Error code | Error message | Link
SYN_0101 | Column header is missing or incorrect. |
SYN_0102 | Flux name is missing. |
SYN_0103 | The flux flux does not match the regular expression [a-zA-Z][a-zA-Z_0-9]*. |
SYN_0104 | The flux flux must have an EDUCT_1 and a PRODUCT_1. |
SYN_0105 | The metabolite metabolite does not match the regular expression [a-zA-Z][a-zA-Z_0-9]*. |
SYN_0106 | Atom entry of metabolite metabolite in flux flux is missing. |
SYN_0107 | Atom entry of metabolite metabolite in flux flux does not match the regular expression #[a-zA-Z0-9]+. |
SYN_0107 | Entry is not declared as a comment. |

#### FLUXES

Error code | Error message | Link
SYN_0201 | Column header is missing or incorrect. |
SYN_0202 | In NAME the flux name is missing. |
SYN_0203 | The entry of FCD must be F, C or D. |
SYN_0204 | The entry of FCD must be either F, C or D. |
SYN_0205 | VALUE must be a floating-point number. |
SYN_0206 | LOW must be a floating-point number. |
SYN_0207 | INC must be a floating-point number or have to match the regular expression #[0-9]+. |
SYN_0208 | UP must be a floating-point number. |
SYN_0209 | NET-block is missing. |
SYN_0210 | XCH-block is missing. |
SYN_0211 | Block NET is empty. |
SYN_0212 | Block XCH is empty. |
SYN_0213 | Blockname is not a valid block. |
SYN_0214 | Entry is not declared as a comment. |
SYN_0215 | Experimental Design WEIGHT must be a floating-point number. |

#### EQUALITIES

Error code | Error message | Link
SYN_0301 | Column header is missing or incorrect. |
SYN_0302 | VALUE must be a floating-point number. |
SYN_0303 | FORMULA must be a linear combination of fluxes. |
SYN_0304 | NET-block is missing. |
SYN_0305 | XCH-block is missing. |
SYN_0306 | NET:::Block NET is empty. |
SYN_0307 | XCH:::Block XCH is empty. |
SYN_0308 | Block is not a valid block. |
SYN_0309 | Entry is not declared as a comment. |

#### INEQUALITIES

Error code | Error message | Link
SYN_0401 | Column header is missing or incorrect. |
SYN_0402 | VALUE must be a floating-point number. |
SYN_0403 | The entry of COMP must be either >= or <=. |
SYN_0404 | FORMULA must be a linear combination of fluxes. |
SYN_0405 | NET-block is missing. |
SYN_0406 | XCH-block is missing. |
SYN_0407 | NET:::Block NET is empty. |
SYN_0408 | XCH:::Block XCH is empty. |
SYN_0409 | Block is not a valid block. |
SYN_0410 | Entry is not declared as a comment. |

#### FLUX_MEASUREMENTS

Error code | Error message | Link
SYN_0501 | Column header is missing or incorrect. |
SYN_0502 | In FLUX_NAME a flux name must be given. |
SYN_0503 | VALUE must be a floating-point number. |
SYN_0504 | DEVIATION must be a floating-point number. |
SYN_0505 | Entry is not declared as a comment. |

#### LABEL_INPUT

Error code | Error message | Link
SYN_0601 | Column header is missing or incorrect. |
SYN_0602 | In META_NAME a metabolite name must be given. |
SYN_0603 | The expression of ISOTOPOMER isotopomer must match the regular expression #[01]+. |
SYN_0604 | VALUE must be a floating-point number. |
SYN_0605 | Entry is not declared as a comment. |

#### LABEL_MEASUREMENTS

Error code | Error message | Link
SYN_0701 | Column header is missing or incorrect. |
SYN_0702 | In META_NAME a metabolite name must be given. |
SYN_0703 | VALUE must be a floating-point number. |
SYN_0704 | DEVIATION must be a floating-point number. |
SYN_0705 | The expression of CUM_CONSTRAINTS must match the regular expression #[01x]+(+#[01x]+)*. |
SYN_0706 | Entry is not declared as a comment. |

#### PEAK_MEASUREMENTS

Error code | Error message | Link
SYN_0801 | Column header is missing or incorrect. |
SYN_0802 | In META_NAME a metabolite name must be given. |
SYN_0803 | PEAK_NO must be an integer number. |
SYN_0804 | VALUE_S must be a floating-point number, - or must be empty. |
SYN_0805 | VALUE_D- must be a floating-point number, - or must be empty. |
SYN_0806 | VALUE_D+ must be a floating-point number, - or must be empty. |
SYN_0807 | VALUE_DD must be a floating-point number, - or must be empty. |
SYN_0808 | VALUE_T must be a floating-point number, - or must be empty. |
SYN_0809 | DEVIATION_S must be a floating-point number or must be empty. |
SYN_0810 | DEVIATION_D- must be a floating-point number or must be empty. |
SYN_0811 | DEVIATION_D+ must be a floating-point number or must be empty. |
SYN_0812 | DEVIATION_DD/T must be a floating-point number or must be empty. |
SYN_0813 | Entry is not declared as a comment. |

#### MASS_SPECTROMETRY

Error code | Error message | Link
SYN_0901 | Column header is missing or incorrect. |
SYN_0902 | In META_NAME a metabolite name must be given. |
SYN_0903 | FRACTION must match the regular expression ([0-9]|([0-9]~[0-9]))(,([0-9]|([0-9]~[0-9])))*. |
SYN_0904 | WEIGHT must be an integer number. |
SYN_0905 | VALUE must be a floating-point number. |
SYN_0906 | DEVIATION must be a floating-point number. |
SYN_0907 | Entry is not declared as a comment. |

#### OPTIONS

Error code | Error message | Link
SYN_1101 | Column header is missing or incorrect. |
SYN_1102 | Entry is not declared as a comment. |

### Consistency errors

The next table shows all consistency errors:

#### NETWORK

Error code | Error message | Link
CON_0101 | Flux name is missing. |
CON_0102 | Error occured in flux %%%. Each flux must have an EDUCT_1 and a PRODUCT_1. |
CON_0103 | Error occured in flux %%%. Atom entry of %%% is missing. |
CON_0104 | Error occured in flux %%%. The atom entry of %%% must be #[a-zA-Z1-9]+. |
CON_0105 | Error occured in flux %%%. Atom number of %%% is incorrect, because equal named metabolites must have the same number of atoms. |
CON_0106 | Error occured in flux %%%. Flux name %%% exists allready. Duplicate flux names are not allowed. |
CON_0107 | Error occured in flux %%%. %%% is an input metabolite. An input flux must not have an EDUCT_2 or a PRODUCT_2. |
CON_0108 | Error occured in flux %%%. The expression of flux entry must be [a-zA-Z][a-zA-Z_0-9]* |
CON_0109 | Error occured in flux %%%. The metabolite entry %%% must be [a-zA-Z][a-zA-Z_0-9]* |
CON_0110 | Error occured in flux %%%. %%% is an output metabolite. An output flux must not have an EDUCT_2 or a PRODUCT_2. |
CON_0111 | Error occured in flux %%%. The sum of educt atoms and the sum of product atoms must be equal. |
CON_0112 | Error occured in flux %%%. The atom entry of %%% contains two or more equal named atoms. |
CON_0113 | Error occured in flux %%%. An input flux must not be an output flux. |

#### INEQUALITIES

Error code | Error messages | Link
CON_0201 | The flux %%% does not occure in NETWORK, but all fluxes used in Formula must be defined in NETWORK first. |
CON_0202 | The entry of FORMULA must not have been empty. |
CON_0203 | The entry of COMP must be >= or <=. |

#### FLUXES

Error code | Error messages | Link
CON_0301 | The flux %%% was not defined in NETWORK. Fluxes used in NAME must be defined in NETWORK first. |
CON_0302 | Entry of FCD must be F, C or D |
CON_0303 | The entry of FCD must be F, if LOW, INC and UP is given. |
CON_0304 | Entry of NAME must not be empty.. |
CON_0305 | Experimental Design Weight must hold 0<=ED_WEIGHT<=1. |

#### FLUX_MEASUREMENTS

Error code | Error message | Link
CON_0401 | The flux %%% was not defined in NETWORK. Fluxes used in NAME must be defined in NETWORK first. |
CON_0402 | Entry of FLUX_NAME must not be empty. |

#### LABEL_INPUT

Error code | Error message | Link
CON_0501 | The flux %%% was not defined in NETWORK as an input metabolite. |
CON_0502 | Length of isotopomer must be equal with number of atoms of this metabolite. |
CON_0503 | The expression of isotopomer entry must be #(01)+ |
CON_0504 | Value must be in [0,1]. |
CON_0505 | Entry of META_NAME must not be empty. |
CON_0506 | Entry of ISOTOPOMER must not be empty. |
CON_0507 | Sum over VALUES must be equal 1. |
CON_0508 | All input metabolites must have a setting. |

#### LABEL_MEASUREMENTS

Error code | Error message | Link
CON_0601 | The flux %%% was not defined in NETWORK. Fluxes used in NAME must be defined in NETWORK first. |
CON_0602 | Length of cumomer must be equal with number of atoms of this metabolite. |
CON_0603 | The expression of cumomer entry must be #(01x)+ |
CON_0604 | Value must be in [0,1]. |
CON_0605 | Entry of META_NAME must not be empty. |
CON_0606 | Entry of CUM_CONSTRAINTS must not be empty. |

#### PEAK_MEASUREMENTS

Error code | Error message | Link
CON_0701 | The flux %%% was not defined in NETWORK. Fluxes used in NAME must be defined in NETWORK first. |
CON_0702 | PEAK_NO must be less or equal with number of atoms of this metabolite. |
CON_0703 | Combination of VALUE_* entries is not permitted. |
CON_0704 | Entry of META_NAME must not be empty. |

#### MASS_SPECTROMETRY

Error code | Error message | Link
CON_0801 | The flux %%% was not defined in NETWORK. Fluxes used in NAME must be defined in NETWORK first. |
CON_0802 | FRACTION entry must not contain a value being greater than number of atoms of this metabolite. |
CON_0803 | Entry of WEIGHT must not be greater than number of atoms in FRACTION entry. |
CON_0804 | Entry of META_NAME must not be empty. |
CON_0805 | The expression of fraction entry must be ([0-9]|([0-9]~[0-9]))(,([0-9]|([0-9]~[0-9])))* |

####

## Glossary

metabolite
  what to say here?
input-metabolite
  A metabolite that is an educt of an input-flux. As such it is called an extra-cellular metabolite. It is a feeding metabolite and it is exactly know with which labeling it is fed. No reaction produces this metabolite, it can only be an educt for an input-flux.
output-metabolite
  A metabolite that is an product of an output-flux. As such it is called an extra-cellular metabolite. It is put out by the network. No reaction uses it as a educt, it can only be a product to an output-flux.
Intermediate-metabolites
  Metabolites that are used to formulate reactions using more than two educts or products.
flux
  A context dependent word. It can be a synonym for reaction. Sometimes it's used as abbreviation for flux-rate.
reaction
  Converts metabolites to other metabolites and thereby transits carbon-atoms.
input-flux
  A reaction that has only one input-metabolite as input and only one product metabolite.
output-flux
  A reaction that has only one inner-metabolite as educt and only one product that has to be an output-metabolite.
net-flux-rate
  Denoting the net-production-rate of a flux building product-metabolites out of educt-metabolites. This can be positive or negative, depending on the way the flux is defined.
exchange-flux-rate
  Denoting the rate a reaction is building an equal amount of products (out of educts) and educts (out of products) per time-frame. A uni-directional flux has an exchange-rate of zero. A bi-directional flux has an exchange-rate greater than zero.
extra-cellular
  A metabolite is called extra-cellular if it is not intracellular. Cellular should be translated to 'at the border of the network'.
atom-entry
  is an index that helps to note the transition of an carbon-atom-position in an educt-metabolite to a position in a product-metabolite.

# About this document ...

This document was generated using the LaTeX2`HTML` translator Version 98.1p1 release (March 2nd, 1998)

Copyright © 1993, 1994, 1995, 1996, 1997, Nicos Drakos (http://cbl.leeds.ac.uk/nikos/personal.html), Computer Based Learning Unit, University of Leeds.

The command line arguments were:
latex2html `-split 0 syntax.tex`.

The translation was initiated by root on 1999-08-09